---
title: "Two Routes to the Same Good"
date: 2021-07-17T17:07:35Z
tags: ["truth","the good","unity","diversity","greek philosophy"]
topics: ["philosophy","theology"]
image: img/plato-and-aristotle.jpg
draft: false
---

Plato and Aristotle were very different thinkers. They came at the same fundamental philosophical problems from radically different directions. Rafael nicely characterized this in his famous “School of Athens” painting – Plato, ever the tutor, sternly pointing to the sky; Aristotle, the indignant pupil, gesturing reflexively toward the earth. But this image is somewhat deceiving. To anyone unfamiliar with the territory, you might walk away from the work thinking that Plato and Aristotle differed *fundamentally*, rather than merely *instrumentally*. Indeed, since the Enlightenment, this is the dominant story told about the thinking of the two men: Plato is the “idealist”, concerned with transcendent objects of pure thought, and disdainful of the material world. Aristotle is the “empiricist” (or, at least, “nominalist”), determined to derive his general understandings from the experience of his senses only, and unconcerned with vaporous notions of transcendence. But this characterization is somewhat misleading. Both men were in fact aiming at the same end, and nowhere is it more plain to see, than in their divergent approaches to The Good. Let’s explore why.

Human experience is, in one sense, a series of discrete experiences. One after another, throughout our lives, objects in the world present themselves to us through our senses like a parade of characters on a stage: the shape of a desk lamp, the warmth of fresh baked bread, the scent of mowed lawn, the texture of an emory board, the color of a dollar bill, the sound of thunder, the flavor of soured milk. But how is it that we come to recognize these experiences as the things that they really are – the lamp, the bread, the lawn, the emory board, the dollar bill, the lightning, and the milk? How is it possible for us to deliniate in our minds, between a flower and a cow? between the taste of honey, and the sound of thunder? How do we know about *difference* and *similarity*? about *unity* and *variety*? about the *universal* and the *particular*? In a nutshell, where do patterns – and the ideas we have about them – come from? Both Plato and Aristotle spent their careers ruminating on this question.

Plato says that all of these objects of experience are essentially made up of *ideas*. Even the sense experiences themselves – shape, temperature, scent, texture, color, sound, and flavor – are *ideas* we associate with the ideas of the objects. But how are ideas possible? Plato argued (in the Parmenides, the Republic, and the Meno) that the rational part of the soul was already equipped with knowledge of the universal patterns, imbued in it from its creation in the transcendent realm. When joined to a body, the soul “forgets” its knowledge, and the life well lived is a process of recalling as much of that knowledge as possible, through contemplation of experience. For Plato, there are many different varieties of “chair” only because material existence is an imperfect copy of (indeed, false by degrees of distance from) the transcendent universal “chair”. Our contemplation of chairs of various kinds will help us to get closer to the ideal chair, and in so doing, come to understand the true nature of chairs. The example of the chair will seem like an amusing *reductio* to our ears. But remember, Plato thought this about everything. Not just chairs. What is true for chairs, is also true for goods. Every kind of good, according to Plato, is an imperfect copy of the universal good, and by contemplating the varieties of good, we can come to understand the transcendent Good Itself, against which all things are judged.

All of the transcendent universals (the “Forms”, as they’re commonly called) are analogous to a forger’s die, from which all particulars are cast. For Plato, the goodness in the good wine, the good man, the good idea, the good sword, and the good house, are all cast from the same die. The Form of The Good. But where do these dies come from? And who is doing the casting? Famously, Plato describes all of this in The Timaeus. A powerful demiurge is tasked with the eternal burden of producing new instances from the multitude of forms he has been given to work with. They have been given to him by a nameless being that transcends even the transcendent. A god so powerful, that he is capable of giving birth to the Forms themselves. This god is thought to be the “unknown god” from Acts 17, in the Bible.

But what does Aristotle say? He thinks that our capacity to discern patterns – to be able to name a chair, and judge it to be good – is woven into the fabric of reality itself. Existence, for Aristotle, is fundamentally characterized by its *potential*. There are various kinds of matter, each with their own inherent potentialities that, when compounded with the right form, give rise to the multitude of individual actualities we encounter. A bronze ring is the compound of a quantity of bronze and the formula of a torus. For Aristotle, however, it was not enough for a quantity of bronze, and the formula of a torus to exist. Something must act upon the bronze to combine the two, and in so doing, actualize the potential of the bronze. This is what he called the “efficient” cause. In this instance, that would be an artisan’s labor. But what about beings that have no human artificer? How do oak trees, or moons, or horses come to be? Aristotle’s explanation of this process is complex and confusing at times, and beyond the scope of this essay, but the basic principles are the same as the bronze ring. Living things are the compound of the right kind of matter and special forms called souls, which actualize the potential of the matter out of which they come into being. These beings, he called “substances”, and our grasp of them as individuals, “subjects”.

There is one further subtle point to be made, here. Given that we are ourselves fundamentally the same as everything else in creation (a compound of form and matter), a certain sort of symmetry exists between the human being and all other kinds of beings. It is this symmetry that makes it possible for us to recognize the particular being of other things. Our sense organs function as actualizers of the various kinds of material potential present in other beings, and the rational part of the soul (the mind) actualizes the immaterial form. This is why we can smell a clove of garlic, without our noses turning into garlic cloves, and why we can imagine the Eiffel Tower in our minds, without the Eiffel Tower arising out of the tops of our heads.

Aristotle believed that the form of a being was its rational definition (quite literally, it’s ‘formula’), and that this definition was comprised of various ‘categories’ of being. The ‘substance’, we’ve already covered, and this, Aristotle considered the *essential* or *fundamental* category of each being. The substance is what makes a thing *essentialy* itself. But Aristotle also says there are nine other categories of being, known as ‘accidental’, because they rely on substance for their actuality, and because they are not inherent to the substance itself. For example, a bronze ring could be hot or cold, depending on its environment. It could be shiny or dull, depending on its condition. It could be sailing through the air, or affixed to a warrior’s wrist, depending on the circumstances.

Aristotle believed that all things strove toward their own completion. He called this *telos*, or purpose. This striving toward completion is the fourth kind of “cause” of a thing: the final cause. Every kind of thing has its own kind of completion, and its completion is that thing’s ultimate satisfaction, or ‘good’. In addition, each of the accidental characteristics of a thing could have its own kind of completion, or satisfaction – and as such, it’s own kind of ‘good’. So, for example, the end of an acorn is an oak tree; the end of a sword, is its utility in battle; the end of a vineyard, is a vintage; and the end of a man, is a completed life. Thus, the healthy oak in full bloom is the fully actualized acorn; the flavorful and potent wine, is the fully actualized vineyard; and the life of rational fulfillment well lived, is the fully actualized man. Given that the good is *categorically different*, relative to the *telos* of particular kinds of things, Aristotle did not believe there could be a universal and *absolute* idea of The Good, in the way that Plato did, because each good was *for* some end that was unlike the others. The good oak is alien to the good sword, and those are alien to a good color pigment or a good scent.

But, Aristotle did think that there was a *hierarchy* of goods. The good for the stone was subordinate to the good for the acorn, and that was subordinate to the good for the horse, and all of those, subordinate to the good for man. Aristotle argued that this is because of the nature of man. All other beings have only the capacity to *participate* in being. But man, the *rational animal*, has the capacity to comprehend being, and understand his own participation in it. This is because he is the compound of matter and a form that has *a mind*. Which is to say, he is a being that has the power to create, and to order his creations according to his own purposes. Why is this important? What makes apprehension more of a good than participation? Well, because it means that we share something in common with whatever it is that created being itself.

In order to complete his ontology, Aristotle needed something that functioned as the end of all things: the permanent, unchanging reality that functioned as the first stable premise in every other explanation of the variety of beings. So, in short, a prime matter, a prime mover, a primary cause, and a primary source of formal order, that functioned as the terminus for all explanations, and as the fountain of all of existence. That prime mover, according to Aristotle, is pure actuality and pure reason itself. This being must itself exist beyond the category of being, since it gives rise to the categories themselves. It is not possible to imagine such a being, being outside the category of being itself. The best we can do is to analogize such a being in terms of the activity of contemplation. God is contemplation of the Good, and since God is the source of all that is good, God spends eternity contemplating himself, and in so doing, giving rise to creation. Aristotle regarded the contemplative life the highest kind of good human life, as a result of this conclusion.

Thus, in a roundabout way, Aristotle also believes in an absolute Good In Itself that is very much like Plato’s idea of The Good in some ways, but radically different in others. One could say that Plato begins at the top and works his way down, while Aristotle begins from the bottom and works his way up. But in either case, they both seem to come to the same conclusion: an independent source of all creation that is the reason for why we have the nature that we do, and to whom we must eventually return. But where they differ is in the characterological nature of this being. Plato’s unknown god, and Aristotle’s unmoved mover, are both in one sense impersonal as the source of all creation. But Aristotle’s god is significantly more intentional than Plato’s. The unknown god of Plato merely keeps the wheel of creation in motion, and leaves the rest to his subordinate divines (such as the Fates, the Furies, and the Sirens). Aristotle’s god, however, is *intentional*. He has a purpose in mind for everything he’s created, and it all points back to him, as the source of all purposes, and indeed of the concept of a purpose itself. Neither seems to be overtly *personal*, in the sense that we think of God today, through the veil of two thousand years of Christian theology. That God does, however, seem to be the same Good In Itself, that Plato and Aristotle had in mind.

```[Imported from exitingthecave.com on 28 November 2021]```

